==> vdr-addon-tvmovie2vdr_0.1.5.orig.tar.gz: vdr-addon-tvmovie2vdr-0.1.5.orig/config.pl <==
#!/usr/bin/perl


# Settings
$channelsfile = "/video/channels.conf"; 	# path to channels-datei
$epgfile = "epg.data";			# path to epg-file
$days2download = 5;			# max. 8 days tvmovie, max 21-28 days tvinfo
$clearEPG = 1;				# clear EPG before inserting them into VDR ? 
                                        # 1=true/0=false
$downloadprefix = "downloadfiles/";	# where to write downloaded files?
$updateprefix = "downloadupdatefiles/"; # where to write downloaded updatefiles?
                                        # use a different folder!
$cleanupoldfiles = 0;			# clean "old" cache-files ?
                                        # 1=true/0=false

# settings for TVMovie
our $baseurl = "http://tvmovie.kunde.serverflex.info/onlinedata/xml-gz/";  
our $aendurl = "http://tvmovie.kunde.serverflex.info/onlinedata/xml-aend-gz/";  
our $useupdate = 1;                     # use Updatefiles ? 1=true/0=false

# settings for TVInfo
our $http_base = "http://www.tvinfo.de/";
our $loginURL = "exe.php3?";
our $listeURL = "target=senderlist.inc";
our $http_proxy = "";                   # example: http://172.16.1.1:3128/
our $tvicache_files = 1;                # 1=true/0=false

# settings for TVMerkzettelimport
our $username = "username";
our $password = "password";
our $tvinfoprefix = "TVINFO+";
our $prio="99";
our $lifetime="99";
our $MarginStart = 10;
our $MarginStop = 10;
our $merkzettelURL = "target=merk.inc";

# settings for hoerzu
our $hoerzuurl = "http://www2.hoerzu.de/text/tv-programm/";
our $hoerzuradiourl = "http://www2.hoerzu.de/text/radioprogramm/";

==> vdr-addon-tvmovie2vdr_0.2.7.orig.tar.gz: vdr-addon-tvmovie2vdr-0.2.7.orig/config.pl <==
#!/usr/bin/perl


# Settings
$channelsfile = "/video/channels.conf"; 	# path to channels-datei
$epgfile = "epg.data";			# path to epg-file
$days2download = 7;			# max. 8 days tvmovie, max 21-28 days tvinfo
$clearEPG = 1;				# clear EPG before inserting them into VDR ? 
                                        # 1=true/0=false
$downloadprefix = "downloadfiles/";	# where to write downloaded files?
$updateprefix = "downloadupdatefiles/"; # where to write downloaded updatefiles?
                                        # use a different folder!
$cleanupoldfiles = 0;			# clean "old" cache-files ?
                                        # 1=true/0=false

# settings for TVMovie
our $baseurl = "http://tvmovie.kunde.serverflex.info/onlinedata/xml-gz/";  
our $aendurl = "http://tvmovie.kunde.serverflex.info/onlinedata/xml-aend-gz/";  
our $useupdate = 1;                     # use Updatefiles ? 1=true/0=false

# settings for TVInfo 
# attention: these settings are obsolete since the prohibit the use of their EPG.
our $http_base = "http://www.tvinfo.de/";
our $loginURL = "exe.php3?";
our $listeURL = "target=senderlist.inc";
our $http_proxy = "";                   # example: http://172.16.1.1:3128/
our $tvicache_files = 1;                # 1=true/0=false

# settings for TVMerkzettelimport
our $username = "login";
our $password = "password";
our $tvinfoprefix = "TVINFO+";
our $prio="99";
our $lifetime="99";
our $MarginStart = 10;
our $MarginStop = 10;
our $merkzettelURL = "http://www.tvinfo.de/share/openepg/schedule.php";
our $tmp = "/tmp";

# settings for hoerzu
our $hoerzuurl = "http://www2.hoerzu.de/text/tv-programm/";
our $hoerzuradiourl = "http://www2.hoerzu.de/text/radioprogramm/";

#settings for infosat
our $infosaturl="/video/received_data";
